==> stylelint-config-recommended-8.0.0-1-any.pkg.tar.xz: usr/share/doc/stylelint-config-recommended/CHANGELOG.md <==
# Changelog

## 8.0.0

- Removed: `stylelint` less than `14.8.0` from peer dependencies.
- Added: `keyframe-block-no-duplicate-selectors` rule.

## 7.0.0

- Removed: `stylelint` less than `14.4.0` from peer dependencies.
- Added: `function-no-unknown` rule.

## 6.0.0

- Removed: `stylelint` less than `14.0.0` from peer dependencies.
- Removed: `function-calc-no-invalid` rule.
- Added: `custom-property-no-missing-var-function` rule.

## 5.0.0

- Removed: `stylelint` less than `13.13.0` from peer dependencies.
- Added: `no-invalid-position-at-import-rule` rule.
- Added: `no-irregular-whitespace` rule.
- Fixed: `selector-type-no-unknown` for custom elements.

## 4.0.0

- Removed: `stylelint` less than `13.12.0` from peer dependencies.
- Added: `declaration-block-no-duplicate-custom-properties` rule.
- Added: `named-grid-areas-no-invalid` rule.

## 3.0.0

- Removed: `stylelint` < 10.1.0 from peer dependencies. `stylelint@10.1.0+` is required now.
- Added: `function-calc-no-invalid` rule.

## 2.2.0

- Added: `stylelint@10` to peer dependency range.

## 2.1.0

- Added: `stylelint@9` to peer dependency range.

## 2.0.1

- Removed: `declaration-block-no-redundant-longhand-properties` rule. This time it is actually removed.

## 2.0.0

- Removed: `declaration-block-no-redundant-longhand-properties` rule.
- Removed: `shorthand-property-no-redundant-values` rule.
- Added: `font-family-no-missing-generic-family-keyword` rule.
- Added: `no-descending-specificity` rule.
- Added: `no-duplicate-at-import-rules` rule.
- Added: `no-duplicate-selectors` rule.

## 1.0.0

- Use `stylelint@8`.

## 0.1.0

- Initial release

==> stylelint-config-recommended-9.0.0-1-any.pkg.tar.xz: usr/share/doc/stylelint-config-recommended/CHANGELOG.md <==
# Changelog

## 9.0.0

- Removed: `stylelint` less than `14.10.0` from peer dependencies.
- Added: `annotation-no-unknown` rule.

## 8.0.0

- Removed: `stylelint` less than `14.8.0` from peer dependencies.
- Added: `keyframe-block-no-duplicate-selectors` rule.

## 7.0.0

- Removed: `stylelint` less than `14.4.0` from peer dependencies.
- Added: `function-no-unknown` rule.

## 6.0.0

- Removed: `stylelint` less than `14.0.0` from peer dependencies.
- Removed: `function-calc-no-invalid` rule.
- Added: `custom-property-no-missing-var-function` rule.

## 5.0.0

- Removed: `stylelint` less than `13.13.0` from peer dependencies.
- Added: `no-invalid-position-at-import-rule` rule.
- Added: `no-irregular-whitespace` rule.
- Fixed: `selector-type-no-unknown` for custom elements.

## 4.0.0

- Removed: `stylelint` less than `13.12.0` from peer dependencies.
- Added: `declaration-block-no-duplicate-custom-properties` rule.
- Added: `named-grid-areas-no-invalid` rule.

## 3.0.0

- Removed: `stylelint` < 10.1.0 from peer dependencies. `stylelint@10.1.0+` is required now.
- Added: `function-calc-no-invalid` rule.

## 2.2.0

- Added: `stylelint@10` to peer dependency range.

## 2.1.0

- Added: `stylelint@9` to peer dependency range.

## 2.0.1

- Removed: `declaration-block-no-redundant-longhand-properties` rule. This time it is actually removed.

## 2.0.0

- Removed: `declaration-block-no-redundant-longhand-properties` rule.
- Removed: `shorthand-property-no-redundant-values` rule.
- Added: `font-family-no-missing-generic-family-keyword` rule.
- Added: `no-descending-specificity` rule.
- Added: `no-duplicate-at-import-rules` rule.
- Added: `no-duplicate-selectors` rule.

## 1.0.0

- Use `stylelint@8`.

## 0.1.0

- Initial release
